/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule auto-download-wizard-filter-dialog-view
 */

(function() {
var AutoDownloadWizardFilterDialogView;
var prototype;
var superConstructor;
var ModalDialogView = dixim.common.ModalDialogView;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var $ = dixim.ctt.jQuery;
var escape = dixim.xml.escape;

/**
 * @class AutoDownloadWizardFilterDialogView
 * @extends ModalDialogView
 * @constructor
 * @param {Object} configs
 */
AutoDownloadWizardFilterDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(AutoDownloadWizardFilterDialogView, ModalDialogView);
dixim.autoDownload.AutoDownloadWizardFilterDialogView = AutoDownloadWizardFilterDialogView;
superConstructor = AutoDownloadWizardFilterDialogView.superConstructor;
prototype = AutoDownloadWizardFilterDialogView.prototype;

var NEXT = 'next';
var APPLY = 'apply';
var ADD = 'add';
var CHANGE = 'change';

var TEMPLATE_BODY_CONTENT = [
    '<div id="auto-download-filter-description" class="description-field dlg_main_msg">',
    '<span>', '${description}', '</span>',
    '</div>',
    '<div id="auto-download-filter-operation" class="modal_hd_btns">',
    '<label>',
    '<button id="filter_operation_change" class="ui-btn ui-shadow ui-corner-all">', '${edit}', '</button>',
    '</label>',
    '<label>',
    '<button id="filter_operation_add" class="ui-btn ui-shadow ui-corner-all">', '${append}', '</button>',
    '</label>',
    '</div>',
    '<div id="auto-download-filter-field" class="list-field">',
    '<div id="auto-download-filter-list" class="task-filter-list-field dlg_scroll">', '<table>', '</table>', '</div>',
    '</div>',
    '<div id="auto-download-filter-error">', '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'auto-download-wizard-filter-dialog-'].join('');

    configs.title = configs.title;

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${description}', _('auto_download_filter_description'))
        .replace('${edit}', _('action_bar_edit'))
        .replace('${append}', _('action_bar_append'))

    configs.contentHeight = configs.contentHeight || 'auto';
    configs.buttons = [
        {text: _('dialog_return_menu'), click: dixim.proxy(this.hide, this)},
        {text: _('dialog_apply'), click: dixim.proxy(this._clickApply, this)},
    ];

    this._sources = configs.sources;
    this._filters;
    this._serverInfo = configs.serverInfo;

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._adjustmentAttention = function() {
    if (parseInt($(window).width(), 10) < 540) {
        $('#auto-download-filter-list').css('top', '237px');
    } else {
        $('#auto-download-filter-list').css('top', '167px');
    }
};

prototype._render = function() {
    if (typeof this._serverInfo.sptvCap !== 'undefined' && this._serverInfo.sptvCap.indexOf('DLMV') != -1) {
        $('#auto-download-filter-list').addClass('attention');
        this._adjustmentAttention();
        $(window).on('resize', $.proxy(this._adjustmentAttention, this));
        $('#auto-download-filter-description').append([
            '<br>',
            '<span class="color_red txt_s">', _('auto_download_filter_attention'), '</span>',
        ].join(''));
    }
    $('#filter_operation_change').closest('label').on('click', dixim.proxy(this._clickChange, this));
    $('#filter_operation_add').closest('label').on('click', dixim.proxy(this._clickAdd, this));

    superConstructor.prototype._render.call(this);
};

prototype.registerFilters = function(filters) {
    this._filters = filters;
};

prototype.addFilterList = function() {
    var filtersLen = this._filters.length;
    var tableSelector = $('#auto-download-filter-list table');

    tableSelector.append([
        '<tr>', '<td class="select-filter-checkbox">',
        '<label class="select-pointer">', '<input type="checkbox" />', '<span>', '</span>', '</label>',
        '</td>', '<td>',
        '<select class="select-pointer filter-select-box" disabled>', '</select>',
        '</td>', '</tr>',
    ].join(''));

    for (var i = 0; i < filtersLen; i += 1) {
        tableSelector.find('tr:last-child select').append([
            '<option id="', this._filters[i].filterId, '" value="', this._filters[i].filterId, '">',
            escape(this._filters[i].filterName),
            '</option>',
        ].join(''));
    }
    tableSelector.find('tr:last-child select')
    .addClass('filter-select-box')
    .append([
        '<option id="del" value="del">', _('auto_download_filter_del'), '</option>',
    ].join(''));
    if (filtersLen === 0) {
        tableSelector.find('[type="checkbox"]').prop('disabled', true);
    }
    tableSelector.find('tr:last-child [type="checkbox"]').on('click', dixim.proxy(this._clickCheckbox, this));
    tableSelector.find('tr:last-child select').on('change', dixim.proxy(this._changeSelect, this));
};

prototype.setFilters = function(filterIds) {
    var filterIdsLen = filterIds.length;
    var rowSelector;

    for (var i = 0; i < filterIdsLen; i += 1) {
        rowSelector = $('#auto-download-filter-list table tr:last-child');

        rowSelector.find('[type="checkbox"]').trigger('click');
        rowSelector.find('select').val(filterIds[i]);
    }
};

prototype._changeCheckbox = function() {
    $('#auto-download-filter-list select').prop('disabled', true);

    $('#auto-download-filter-list [type="checkbox"]:checked').closest('tr').find('select').prop('disabled', false);

    if ($('#auto-download-filter-list table tr:last-child [type="checkbox"]').prop('checked')) {
        this.addFilterList();
    }
};

prototype._clickCheckbox = function() {
    this._changeCheckbox();
};

prototype._changeSelect = function() {
    $('#auto-download-filter-list select').each(function() {
        if ($(this).val() === 'del') {
            $(this).closest('tr').remove();
        }
    });
};

prototype._clickApply = function() {
    var info = {};

    info.filters = [];
    $('#auto-download-filter-list [type="checkbox"]:checked').each(function() {
        info.filters.push(parseInt($(this).closest('tr').find('select').val(), 10));
    });

    this.dispatchEvent(new Event(APPLY, info));
};

prototype._clickChange = function() {
    var info = {};
    var filters = this._filters;
    var filtersLen = filters.length;
    var idList = [];
    var idListLen;

    info.filters = [];
    idList = [];
    $('#auto-download-filter-list [type="checkbox"]:checked').each(function() {
        idList.push(parseInt($(this).closest('tr').find('select').val(), 10));
    });
    idListLen = idList.length;

    for (var i = 0; i < filtersLen; i += 1) {
        for (var j = 0; j < idListLen; j += 1) {
            if (filters[i].filterId === idList[j]) {
                info.filters.push(filters[i]);
            }
        }
    }
    this.dispatchEvent(new Event(CHANGE, info));
};

prototype._clickAdd = function() {
    this.dispatchEvent(new Event(ADD));
};

prototype.putFilterList = function() {
    var filters = this._filters;
    var filtersLen = filters.length;
    var selectSelector = $('#auto-download-filter-list table select');
    var optionSelector;

    for (var i = 0; i < filtersLen; i += 1) {
        optionSelector = selectSelector.find(['option#', filters[i].filterId].join(''));
        if (optionSelector.length !== 0) {
            optionSelector.text(filters[i].filterName);
        } else {
            selectSelector.find('#del').before([
                '<option id="', filters[i].filterId, '" value="', filters[i].filterId, '">', escape(filters[i].filterName), '</option>',
            ].join(''));
            if (selectSelector.val() === 'del') selectSelector.val(filters[i].filterId);
        }
    }

    selectSelector.closest('table').find('[type="checkbox"]').prop('disabled', (filtersLen === 0));
};

prototype.cleanFilterList = function() {
    $('#auto-download-filter-list table select option').not('#del').text('');
};

}());
