/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule operation-menu-dialog-controller
 */

(function() {
var OperationMenuDialogController;
var prototype;
var superConstructor;
var OperationMenuDialogView = dixim.autoDownload.OperationMenuDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var AutoDownloadWizardDialogController = dixim.autoDownload.AutoDownloadWizardDialogController;
var DeletionDialogController = dixim.autoDownload.DeletionDialogController;
var AutoDownloadStatusDialogController = dixim.autoDownload.AutoDownloadStatusDialogController;
var Enum = dixim.ctt.util.Enum;

/**
 * @class OperationMenuDialogController
 * @constructor
 * @param {Object} configs
 */
OperationMenuDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(OperationMenuDialogController, EventTarget);
dixim.autoDownload.OperationMenuDialogController = OperationMenuDialogController;
prototype = OperationMenuDialogController.prototype;
superConstructor = OperationMenuDialogController.superConstructor;

var ADD_TASK = 'addTask';
var CHANGE_TASK = 'changeTask';
var DELETE_TASK = 'deleteTask';
var CONFIRM_STATUS = 'confirmStatus';
var UPDATE = 'update';
var CLOSE = 'close';

var Mode = Enum.fetch('DELETION');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'operation-menu-dialog'].join('');

    this._view = new OperationMenuDialogView(configs);
    this._view.addEventListener(ADD_TASK, this._clickAddTask, this);
    this._view.addEventListener(CHANGE_TASK, this._clickChangeTask, this);
    this._view.addEventListener(DELETE_TASK, this._clickDeleteTask, this);
    this._view.addEventListener(CONFIRM_STATUS, this._clickConfirmStatus, this);

    this._taskList = configs.taskList || [];
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._clickAddTask = function() {
    var query = {};
    var controller;

    query.title = _('auto_download_operation_add_task');
    controller = new AutoDownloadWizardDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickChangeTask = function() {
    var query = {};
    var controller;

    if (this._taskList.length !== 1) {
        this._errorDialog(_('auto_download_operation_change_task'), _('auto_download_one_only_error'));
        return;
    }

    query.title = _('auto_download_operation_change_task');
    query.taskInfo = this._taskList[0];
    controller = new AutoDownloadWizardDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickDeleteTask = function() {
    var query = {};
    var controller;

    if (this._taskList.length === 0) {
        this._errorDialog(_('auto_download_operation_delete_task'), _('auto_download_not_selected_error'));
        return;
    }

    query.contents = this._taskList;
    query.mode = Mode.TASK;
    query.doubleDialog = true;
    controller = new DeletionDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickConfirmStatus = function() {
    var query = {};
    var controller;

    if (this._taskList.length !== 1) {
        this._errorDialog(_('auto_download_operation_change_task'), _('auto_download_one_only_error'));
        return;
    }

    query.taskInfo = this._taskList[0];
    controller = new AutoDownloadStatusDialogController(query);
    controller.start();
};

prototype._callbackUpdate = function() {
    this.stop();
    this.dispatchEvent(new Event(UPDATE));
};

prototype._errorDialog = function(title, text) {
    var query = {};

    query.id = this._id;
    query.title = title;
    query.description = text;
    query.doubleDialog = true;
    this.dialog = new ErrorModalDialogView(query);
    this.dialog.show();
};

}());
