/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule search-dialog-controller
 */

(function() {
var SearchDialogController;
var prototype;
var superConstructor;
var SearchDialogView = dixim.contents.SearchDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var _ = dixim.ctt.ResourceBundle.get;

/**
 * @class SearchDialogController
 * @constructor
 * @param {Object} configs
 */
SearchDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(SearchDialogController, EventTarget);
dixim.contents.SearchDialogController = SearchDialogController;
prototype = SearchDialogController.prototype;
superConstructor = SearchDialogController.superConstructor;

var SEARCH = 'search';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'search-dialog'].join('');

    this._view = new SearchDialogView(configs);
    this._view.addEventListener(SEARCH, this._clickSearch, this);
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._clickSearch = function(e) {
    var title = e.args.title;

    if (title === '') {
        this._view.error(_('contents_search_no_title'));
        return;
    }
    this.dispatchEvent(new Event(SEARCH, {title: title}));
    this.stop();
};

}());
