/**
 * @module dixim
 * @submodule contents
 */
dixim.namespace('dixim.contents');

/**
 * @module contents
 * @submodule search-dialog-view
 */

(function() {
var SearchDialogView;
var prototype;
var superConstructor;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var ModalDialogView = dixim.common.ModalDialogView;
var $ = dixim.ctt.jQuery;
var PlaceHolder = dixim.ctt.util.PlaceHolder;
var TickerView = dixim.ctt.TickerView;

/**
 * @class SearchDialogView
 * @constructor
 * @param {Object} configs
 */
SearchDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(SearchDialogView, ModalDialogView);
dixim.contents.SearchDialogView = SearchDialogView;
prototype = SearchDialogView.prototype;
superConstructor = SearchDialogView.superConstructor;

var SEARCH = 'search';

var TEMPLATE_BODY_CONTENT = [
    '<div class="search-description-field dlg_main_msg none_border_bottom">', '${description}', '</div>',
    '<div id="search-error-field">', '</div>',
    '<div>',
    '<input type="text" id="search-title" class="search-field form_block placeholder_position" />',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'search-dialog-'].join('');

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${description}', _('contents_search_description'));

    configs.title = _('contents_search_title');
    configs.contentHeight = configs.contentHeight || 'auto';
    configs.closeButton = dixim.proxy(this.hide, this);
    configs.buttons = [
        {
            text: _('dialog_close'),
            click: dixim.proxy(this.hide, this),
        },
        {
            text: _('dialog_search'),
            click: dixim.proxy(this._clickSearch, this),
        },
    ];
    this._ticker = null;

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function() {
    this._ticker = new TickerView({
        containerNode: $('#search-error-field'),
        type: 'error',
    });

    PlaceHolder.set($('#search-title'), _('contents_search_placeholder'));

    superConstructor.prototype._render.call(this);
};

prototype.error = function(text) {
    this._ticker.setText(text);
    this._ticker.show();
};

prototype._clickSearch = function() {
    var title = ($('#search-title.placeholding').length === 0) ? $('#search-title').val() : '';

    this.dispatchEvent(new Event(SEARCH, {title: title}));
};

}());
