/**
 * @module dixim
 * @submodule vdms
 */
dixim.namespace('dixim.vdms');

/**
 * @module vdms
 * @submodule aggregation-operation-menu-dialog-controller
 */

(function() {
var AggregationOperationMenuDialogController;
var prototype;
var superConstructor;
var AggregationOperationMenuDialogView = dixim.vdms.AggregationOperationMenuDialogView;
var EventTarget = dixim.event.EventTarget;
var Event = dixim.event.Event;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var DeletionDialogController = dixim.vdms.DeletionDialogController;
var ProgressDialogController = dixim.vdms.ProgressDialogController;
var Enum = dixim.ctt.util.Enum;

/**
 * @class AggregationOperationMenuDialogController
 * @constructor
 * @param {Object} configs
 */
AggregationOperationMenuDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AggregationOperationMenuDialogController, EventTarget);
dixim.vdms.AggregationOperationMenuDialogController = AggregationOperationMenuDialogController;
prototype = AggregationOperationMenuDialogController.prototype;
superConstructor = AggregationOperationMenuDialogController.superConstructor;

var UPDATE = 'update';
var CLOSE = 'close';
var CHANGE = 'change';
var PAUSE = 'pause';
var RESTART = 'restart';
var DELETE = 'delete';

var Mode = Enum.fetch('PROGRESS');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'aggregation-operation-menu-dialog'].join('');

    this._view = new AggregationOperationMenuDialogView(configs);
    this._view.addEventListener(CHANGE, this._clickChange, this);
    this._view.addEventListener(PAUSE, this._clickPause, this);
    this._view.addEventListener(RESTART, this._clickRestart, this);
    this._view.addEventListener(DELETE, this._clickDelete, this);

    this._serverList = configs.serverList || [];
    this._isAggregatedDevice = configs.isAggregatedDevice;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._clickChange = function() {
    var query = {};

    query.contents = this._serverList;
    query.doubleDialog = true;
    query.mode = (this._isAggregatedDevice) ? Mode.NON_AGGREGATION : Mode.AGGREGATION;
    controller = new ProgressDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickPause = function() {
    var query = {};

    query.contents = this._serverList;
    query.doubleDialog = true;
    query.mode = Mode.PAUSE;
    controller = new ProgressDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickRestart = function() {
    var query = {};

    query.contents = this._serverList;
    query.doubleDialog = true;
    query.mode = Mode.RESTART;
    controller = new ProgressDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._clickDelete = function() {
    var controller;
    var query = {};

    query.contents = this._serverList;
    controller = new DeletionDialogController(query);
    controller.addEventListener(UPDATE, this._callbackUpdate, this);
    controller.start();
};

prototype._callbackUpdate = function() {
    this.stop();
    this.dispatchEvent(new Event(UPDATE));
};

prototype._errorDialog = function(title, text) {
    var query = {};
    var dialog;

    query.id = this._id;
    query.title = title;
    query.description = text;
    query.doubleDialog = true;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

}());
