/**
 * @module ctt
 * @submodule destination-storage-listing-view
 */
(function() {
var Event = dixim.event.Event;
var ItemListingView = dixim.ctt.ItemListingView;
var Formatter = dixim.ctt.util.Formatter;
var escapeHtml = dixim.xml.escape;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var DestinationStorageListingView;
var superConstructor;
var prototype;

/**
 * @class DestinationStorageListingView
 * @extends ItemListingView
 * @constructor
 * @param {Object} configs
 */
DestinationStorageListingView = function(configs) {
  ItemListingView.call(this, configs);
};
dixim.inherit(DestinationStorageListingView, ItemListingView);
dixim.ctt.DestinationStorageListingView = DestinationStorageListingView;
prototype = DestinationStorageListingView.prototype;
superConstructor = DestinationStorageListingView.superConstructor;

prototype._initialize = function(configs) {
  var schema = {title: 'friendlyName'};
  var cfg = {
    className: 'ctt-destination-storage-listing-view',
    elementIdPrefix: 'ctt-destination-storage-listing-view-'
  };

  cfg = dixim.extend(cfg, configs);
  cfg.schema = dixim.extend(schema, configs.schema || {});
  superConstructor.prototype._initialize.call(this, cfg);
};

var TEMPLATE_ROW = ['<li id="${id}" class="ctt-item-listing-view-row">',
                    '<div class="ctt-item-listing-view-row-title">${title}</div>',
                    '<div class="ctt-destination-storage-listing-view-row-capacity">${capacity}</div>',
                    '</li>'].join('');

var TEMPLATE_ROW_CAPACITY = ['<div class="ctt-destination-storage-listing-view-row-capacity-gauge"></div>',
                             '<div class="ctt-destination-storage-listing-view-row-capacity-value"></div>'
                             ].join('');

/**
 * @method _createRowElementHtml
 * @param {Object} record
 * @param {Number} index
 * @protected
 */
prototype._createRowElementHtml = function(record, index) {
  var id;
  var html;
  var title;

  if (!!!(id = this._makeElementId(record))) {
    return null;
  }

  title = this._getRecordProperty(record, 'title') || '';
  html = TEMPLATE_ROW.
         replace('${id}', id).
         replace('${title}', escapeHtml(title)).
         replace('${capacity}', TEMPLATE_ROW_CAPACITY);

  return html;
};

prototype._createRowElementNode = function(record, index, html) {
  var total;
  var available;
  var ratio;
  var node;

  node = superConstructor.prototype._createRowElementNode.apply(this, arguments);

  total = record.totalCapacity;
  available = record.availableCapacity;

  if (!!!total || typeof available === 'undefined') {
    return node;
  }

  ratio = Math.floor(((total - available) / total) * 100);

  $('.ctt-destination-storage-listing-view-row-capacity-gauge', node).
    progressbar({value: ratio});

  if (ratio < 1) {
    node.addClass('ctt-destination-storage-listing-view-row-no-space');
  }

  total = Formatter.stringifySize(total);
  available = Formatter.stringifySize(available);
  //if availavle is 0B
  if (available === "") {
    available = '0B';
    node.addClass('ctt-destination-storage-listing-view-no-available');
    $(node).children('.ctt-item-listing-view-row-title').append(
      [
        '<span class="ctt-item-no-available-storage">',
        '&nbsp&nbsp&nbsp',
        _('ctt_destination_storage_listing_wizard_page_view_no_available_storage'),
        '</span>'
      ].join('')
    );
  }
  $('.ctt-destination-storage-listing-view-row-capacity-value', node).
    text(_('ctt_destination_storage_listing_view_row_capacity_value', available, total));

  return node;
};

}());
