/**
 * @module ctt
 * @submodule ctt-ad
 */
dixim.namespace('dixim.ctt.ad');

/**
 * @module ctt-ad
 * @submodule setting-dialog-controller
 */

(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var SettingDialogView = dixim.ctt.ad.SettingDialogView;
var AutoDownloadApiClient = dixim.ctt.ad.AutoDownloadApiClient;
var ErrorDialog = dixim.ctt.ErrorDialog;

var SettingDialogController;
var prototype;

/**
 * @class SettingDialogController
 * @constructor
 * @param {Object} configs
 * @param {ContentsTransferApiClient} [configs.model]
 */
SettingDialogController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(SettingDialogController, EventTarget);
dixim.ctt.ad.SettingDialogController = SettingDialogController;
prototype = SettingDialogController.prototype;

/**
 * Triggered when the deletion has been done.
 *
 * @event close
 * @param {Event} event
 * @param {Object} event.args
 * @param {Object} event.args.deleted true if the deletion is completed, otherwise false.
 */
var CLOSE = 'close';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {Object} configs.targetItems
 * @param {ContentsTransferApiClient} [configs.model]
 */
prototype._initialize = function(configs) {
  configs = configs || {};

  this._model = new AutoDownloadApiClient();
  this._view = new SettingDialogView(configs);
  this._session = null;
  this._queue = [];
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  v.addEventListener('save', this._didClickSave, this);
  v.addEventListener('cancel', this._didClickCancel, this);

  v.show();
};

prototype._didClickSave = function() {
  var size_byte = parseInt($("#empty_capacity").val(), 10) * 1024 * 1024 * 1024;
  var allowMoveRadio = $("input#yes_radio").is(":checked");

  this._model.updateMoveSetting({
    allowMove: allowMoveRadio,
    error: dixim.proxy(function() {
      this._showErrorDialog("ctt_error_dialog_default");
    }, this)
  });
  this._model.updateStorageCapacityThreshold({
    size: size_byte,
    error: dixim.proxy(function() {
      this._showErrorDialog("ctt_error_dialog_default");
    }, this)
  });
  this.destroy();
};

prototype._didClickCancel = function() {
  this._view.destroy();
  this.dispatchEvent(new Event(CLOSE));
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

/**
 * @method _showErrorDialog
 * @private
 * @param {String} error error ID.
 */
prototype._showErrorDialog = function(error) {
  var dialog;
  var query = {type: error};

  if (!!this._modal) {
    this._modal.destroy();
    this._modal = null;
  }
  if (typeof error.title !== "undefined") {
    query.title = error.title;
  }
  if (typeof error.description !== "undefined") {
    query.description = error.description;
  }

  dialog = new ErrorDialog(query);
  dialog.addEventListener('close', this._didCloseModalDialog, this);

  dialog.show();
  this._modal = dialog;
};

prototype._didCloseModalDialog = function(e) {
  var args = e.args;

  if (this._modal === args.dialog) {
    this._modal.destroy();
    this._modal = null;
  }
};

}());
