/**
 * @module ctt
 * @submodule error-dialog
 */
(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var ErrorDialog;
var prototype;

/**
 * @class ErrorDialog
 * @constructor
 * @param {Object} configs
 */
ErrorDialog = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(ErrorDialog, EventTarget);
dixim.ctt.ErrorDialog = ErrorDialog;
prototype = ErrorDialog.prototype;

/**
 * Triggered when the dialog has been closed from screen.
 *
 * @event close
 * @param {Event} event
 * @param {Object} event.args
 * @param {ErrorDialog} event.args.dialog
 * @param {Number} event.args.buttonIndex
 */
var CLOSE = 'close';

var TEMPLATE_CONTAINER = '<div class="ctt-error-dialog-content-wrapper" />';
var TEMPLATE_DIALOG_CONTENT = '<div class="ctt-error-dialog-content">${description}</div>';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {String} configs.containerNode
 */
prototype._initialize = function(configs) {
  if (!!!configs) return;
  this._type = configs.type;
  this._title = configs.title;
  this._description = configs.description;
};

/**
 * @method _createView
 * @private
 */
prototype._createView = function() {
  var desc = '';
  var title = '';
  var bodyContent;
  var container;
  var type;

  if (!!(type = this._type)) {
    title = _(type + '_title');
    desc = _(type + '_description');
  }

  if (!!this._title) {
    title = this._title;
  }
  if (!!this._description) {
    desc = this._description;
  }

  container = $(TEMPLATE_CONTAINER);
  bodyContent = $(TEMPLATE_DIALOG_CONTENT.replace('${description}', desc));

  this._view = container.append(bodyContent).dialog({
    buttons: [
      {
        text: _('ctt_dialog_button_label_close'),
        click: $.proxy(this._didClickClose, this)
      }
    ],
    title: title,
    modal: true,
    width: 400,
    resizable: false,
    autoOpen: false,
    close: $.proxy(this._didClose, this)
  });
  $('button').contents().wrap('<a href="#"></a>');
};

prototype._didClickClose = function(e) {
  this._view.dialog('close');
};

prototype._didClose = function(e) {
  var args = {};

  args.buttonIndex = 0;
  args.dialog = this;
  this.dispatchEvent(new Event(CLOSE, args));
};

prototype.convertButtons = function() {
    var default_buttons = [];
    var default_buttons_class = [];

    $('.ui-dialog-buttonset button', this._view.parent()).each(function() {
        default_buttons.push($(this).html());
        default_buttons_class.push($(this).prop('class'));
    });
    $('.ui-dialog-buttonset button', this._view.parent()).remove();
    for (var i = 0; i < default_buttons.length; i += 1) {
        $('.ui-dialog-buttonset', this._view.parent()).append([
            '<div class="div-btn">', default_buttons[i], '</div>'
        ].join(''));
        if (default_buttons_class[i] !== '') {
            $('.ui-dialog-buttonset > div:last-child').addClass(default_buttons_class[i]);
        }
        $('.ui-dialog-buttonset > div:last-child').click($.proxy(this._didClickClose, this));
    }
};

/**
 * @method show
 */
prototype.show = function() {
  if (!!!this._view) {
    this._createView();
  }
  this._view.dialog('open');

  this.convertButtons();
};

/**
 * @method hide
 */
prototype.hide = function() {
  this._view.dialog('close');
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.dialog('destroy');
  this._view.remove();
  this._view = null;
};

}());
