#!/bin/sh

BASE=/opt/dms-dtcp
PGM=dms_sync
PGM_PATH=$BASE/$PGM
CONF=conf
INIT_DMS_PATH=$BASE/init_dms.sh

MAX_USER_WATCHES=100000
MAX_USER_WATCHES_PATH=/proc/sys/fs/inotify/max_user_watches

C_CRS=/usr/local/bin/check_record_status
F_CRS_PID=/var/run/check_record_status.pid

start_crs()
{
	start-stop-daemon --start --quiet --pidfile "${F_CRS_PID}" --make-pidfile --background --exec "${C_CRS}" --test > /dev/null \
		|| return 1
	start-stop-daemon --start --quiet --pidfile "${F_CRS_PID}" --make-pidfile --background --exec "${C_CRS}" -- \
		|| return 2
}

stop_crs()
{
	start-stop-daemon --stop --quiet --retry=TERM/30/KILL/5 --pidfile "${F_CRS_PID}"
	RETVAL="${?}"
	[ "${RETVAL}" = 2 ] && return 2

	/bin/rm -f "${F_CRS_PID}"
	return "${RETVAL}"
}

init_cds() {
    echo "Initing cds..."
    ps aux | grep $PGM | grep -v grep > /dev/null
    if [ $? -eq 0 ]; then
    echo "Error"
        exit 1
    else
        "$INIT_DMS_PATH" cds
    fi
}

start() {
    export DU_LOG_LEVEL=0
#    export DIXIM_CDSRDB_SQLITE_ENABLE_SYNCHRONOUS=1
#    export DIXIM_DMS_SYNC_USE_LMT_DB=1
    if [ -f $MAX_USER_WATCHES_PATH -a -w $MAX_USER_WATCHES_PATH ]; then
        echo $MAX_USER_WATCHES > $MAX_USER_WATCHES_PATH
    fi
    echo "Starting $PGM..."
    cd "$BASE"
    "$PGM_PATH" "$BASE/$CONF" "$BASE"

    start_crs
}

stop() {
    echo "Shutting down $PGM..."
    stop_crs

    MAX_SEC=`date +%s`
    MAX_SEC=`expr $MAX_SEC + 60`
    killall $PGM
    ps aux | grep $PGM | grep -v grep > /dev/null
    while [ $? -eq 0 ]; do
        sleep 1
        if [ `date +%s` -gt  $MAX_SEC ]; then
                killall -9 $PGM
                break
        fi;
        ps aux | grep $PGM | grep -v grep > /dev/null
    done
    result=$?
    if [ $result -eq 1 ]; then
        result=0
    fi
    return $result
}

restart() {
        stop
        sleep 5
        start
}

case "$1" in
  start)
        start
        ;;
  stop)
        stop
        ;;
  restart)
        restart
        ;;
  init-cds)
       init_cds
        ;;
  *)
        echo "Usage: $0 {start|stop|restart|init-cds}"
        exit 1
esac

exit $?
